@@ -21,6 +21,7 @@ use constant DEFAULT_LEVEL      => 5;
 use constant DEFAULT_SORT_KEYS  => 1;
 use constant DEFAULT_QUOTE_KEYS => 0;
 use constant DEFAULT_DEEP_COPY  => 1;
+use constant DEFAULT_PURITY     => 1;
 
 use constant DEFAULT_BASE_DIR => '/tmp';
 use constant MAX_FRAME => 10;
@@ -37,7 +38,7 @@ Version 0.20
 
 =cut
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 $VERSION = eval $VERSION;
 
@@ -150,9 +151,10 @@ sub new
          history        => [],
          dumps          => exists $args{ dumps } ? $args{ dumps } : 1,
          dump_depth     => $args{ dump_depth } || 0,
-         sort_keys      => exists $args{ sort_keys }  ? $args{ sort_keys }  : DEFAULT_SORT_KEYS,
+         sort_keys      => exists $args{ sort_keys }  ? $args{ sort_keys  } : DEFAULT_SORT_KEYS,
          quote_keys     => exists $args{ quote_keys } ? $args{ quote_keys } : DEFAULT_QUOTE_KEYS,
-         deep_copy      => exists $args{ deep_copy } ? $args{ deep_copy } : DEFAULT_DEEP_COPY,
+         deep_copy      => exists $args{ deep_copy  } ? $args{ deep_copy  } : DEFAULT_DEEP_COPY,
+         purity         => exists $args{ purity     } ? $args{ purity     } : DEFAULT_PURITY,
          filename       => $args{ filename },
          autoflush      => exists $args{ autoflush } ? $args{ autoflush } : 1,
         _fh             => undef,
@@ -301,7 +303,20 @@ sub deep_copy
     return $self->{ deep_copy };
 }
 
+=head3 purity
 
+Sets C<$Data::Dumper::Purity>.
+
+ $log->purity( 0 );
+
+=cut
+
+sub purity
+{
+    my ( $self, $arg ) = @_;
+    $self->{ purity } = $arg if defined $arg;
+    return $self->{ purity };
+}
 
 =head3 filename
 
@@ -376,6 +391,8 @@ sub msg
     
     local $Data::Dumper::Deepcopy = $self->deep_copy;
 
+    local $Data::Dumper::Purity = $self->purity;
+
     if ( $level !~ /^\d+$/ )
     {
         # bad log level, so push the 'level' to the 'things'
@@ -422,9 +439,9 @@ sub msg
     {
         if ( my $label = ref $thing )
         {
-            if ( $self->dumps || $level == 0 )
+            if ( $self->dumps || $level == FATAL )
             {
-                $Data::Dumper::Maxdepth = 9 if $level == 0;
+                $Data::Dumper::Maxdepth = 0 if $level == FATAL;
 
                 my $dumped = Data::Dumper->Dump( [ $thing ], [ $label ] );
 
